<?php

/***************************************************************************\
 *  SPIP, Systeme de publication pour l'internet                           *                                              *
 *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
 *                                                                         *
 *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
 *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
\***************************************************************************/

/**
 * Gestion de l'action editer_depublie et de l'API d'édition d'une dépublication
 *
 * @package SPIP\Depublies\Edition
 */

if (!defined("_ECRIRE_INC_VERSION")) {
	return;
}


/**
 * Action d'édition d'une dépublication dans la base de données dont
 * objet|id_objet|date|statut sont donné en paramètre de cette fonction ou
 * en argument de l'action sécurisée
 *
 * Si l'objet et l'identifiant de l'objet n'existent pas, on crée alors une nouvelle dépublication,
 *
 * @uses depublie_inserer()
 * @uses depublie_modifier()
 *
 * @param string $arg
 * En absence utilise l'argument
 *     de l'action sécurisée.
 *
 * 
 * @example
 * ```
 * 
 * [(#URL_ACTION_AUTEUR{editer_depublie,#OBJET/#ID_OBJET/#GET{date}/#GET{statut}})]
 *
 * $editer_depublie = charger_fonction('editer_depublie', 'action');
 * $editer_depublie("$objet/$id_objet/$date_depublie/'archive'");
 * 
 * ```
 *
 */
function action_editer_depublie_dist($arg = null) {
	
	if (is_null($arg)) {
		$securiser_action = charger_fonction('securiser_action', 'inc');
		$arg = $securiser_action();
	}
		
	if (
		list($objet, $id_objet, $date, $statut) = explode('/', $arg)
		and intval($id_objet) > 0
	){
	
		if(!$statut){
			if (lire_config('depublie/statut_depublie')){
				$statut = lire_config('depublie/statut_depublie');
			} else {
				$statut = 'depublie';
			}
		}
		
		//conformité de la date
		$date = date_format_sql($date);
		if (!$date) {
			spip_log("verification de $date a échoué dans action/",'editer_depublie');
			return;
		}
		
		$id_deja = sql_getfetsel('id_objet','spip_depublies','id_objet='.intval($id_objet).' AND objet='.sql_quote($objet));
		if($id_deja) {
			depublie_modifier($objet, $id_objet, $date, $statut);
		} else {
			depublie_inserer($objet, $id_objet, $date, $statut);
		}
	}
}


/**
 * Insérer une nouvelle entrée dans spip_depublies
 *
 * @pipeline_appel pre_insertion
 * @pipeline_appel post_insertion
 *
 *
 *	   Objet dont la date de depublication est à insérer
 * @param string $objet
 *     Identifiant de l'objet dont la date de depublication est à insérer
 * @param int $id_objet
 * @param string $date (de préférence au format sql)
 * @param string $statut
 * statut que objet/id_objet aura à sa dépublication
 *
 * @return bool
 *     - 1 si aucune erreur
 */
function depublie_inserer($objet, $id_objet, $date, $statut) {
	
	$champs = array(
		'objet' => $objet,
		'id_objet' => $id_objet,
		'date_depublie' => $date,
		'statut' => $statut, 
	);

	// Envoyer aux plugins
	$champs = pipeline('pre_insertion',
		array(
			'args' => array(
				'table' => 'spip_depublies',
			),
			'data' => $champs
		)
	);

	$new_depublie = sql_insertq("spip_depublies", $champs);
	
	pipeline('post_insertion',
		array(
			'args' => array(
				'table' => 'spip_depublies',
				'id_objet' => $id_objet,
				'objet' => $objet,
			),
			'data' => $champs
		)
	);

	return "$objet-$id_objet";
}

/**
 * Modifier une entrée de spip_depublies
 *
 * fonctions de modification de la date d'une dépublication
 *
 *	   Objet dont la date de depublication est à modifier
 * @param string $objet
 *     Identifiant de l'objet dont la date de depublication est à modifier
 * @param int $id_objet
 * @param string $date (de préférence au format sql)
 * @param string $statut
 * statut que objet/id_objet aura à sa dépublication
 *
 * @return bool
 *     - 1 si aucune erreur
 *
 */
function depublie_modifier($objet, $id_objet, $date, $statut) {
	
	spip_log("depublie_modifier pour $objet N° $id_objet le $date en $statut",'editer_depublie');
	
	// Modification de l'objet à dépublier
	$depublie_objet = sql_updateq("spip_depublies", array( 'date_depublie' => $date, 'statut' => $statut),'id_objet='.intval($id_objet)." AND objet=".sql_quote($objet));

	return $depublie_objet;
}


/**
 * verifie et retourne la date au format SQL
 * avec soustraction ou ajout de DateInterval
 *
 * @param string $date 
 * @param string $di format DateInterval
 * return string date au format mysql
**/
function date_format_sql($date, $di=null, $invert=false){
	if(strtotime($date)){ //verifie que c'est bien une date
		$date = new DateTime($date);
		if($di){
			$datemodif = new DateInterval($di); //'P1D' = +1jour
			if($invert){
				$datemodif->invert = 1;//invert true = -1jour
			}
			$date = $date->add($datemodif);
		}
		$date = $date->format('Y-m-d H:i:s');
		return $date;
	}
	return false;
}